@@ -37,11 +37,7 @@
 #include "preferences.h"
 #include "applier.h"
 
-#ifdef HAVE_GTK_MULTIHEAD
 static BGApplier **bg_appliers;
-#else
-static BGApplier *bg_applier;
-#endif
 static BGPreferences *prefs;
 
 static guint applier_idle_id = 0;
@@ -49,13 +45,9 @@ static guint applier_idle_id = 0;
 static gboolean
 applier_idle (gpointer data)
 {
-#ifdef HAVE_GTK_MULTIHEAD
 	int i;
 	for (i = 0; bg_appliers [i]; i++)
 		bg_applier_apply_prefs (bg_appliers [i], prefs);
-#else
-	bg_applier_apply_prefs (bg_applier, prefs);
-#endif
 	applier_idle_id = 0;
 	return FALSE;
 }
@@ -75,7 +67,6 @@ background_callback (GConfEntry *entry)
 void
 gnome_settings_background_init (GConfClient *client)
 {
-#ifdef HAVE_GTK_MULTIHEAD
 	GdkDisplay *display;
 	int         n_screens;
 	int         i;
@@ -93,9 +84,6 @@ gnome_settings_background_init (GConfClient *client)
 		bg_appliers [i] = BG_APPLIER (bg_applier_new_for_screen (BG_APPLIER_ROOT, screen));
 	}
 	bg_appliers [i] = NULL;
-#else
-	bg_applier = BG_APPLIER (bg_applier_new (BG_APPLIER_ROOT));
-#endif
 
 	prefs = BG_PREFERENCES (bg_preferences_new ());
 	bg_preferences_load (prefs);
@@ -106,9 +94,7 @@ gnome_settings_background_init (GConfClient *client)
 void
 gnome_settings_background_load (GConfClient *client)
 {
-#ifdef HAVE_GTK_MULTIHEAD
 	int i;
-#endif
 
 	/* If this is set, nautilus will draw the background and is
 	 * almost definitely in our session.  however, it may not be
@@ -121,10 +107,6 @@ gnome_settings_background_load (GConfClient *client)
 	if (gconf_client_get_bool (client, "/apps/nautilus/preferences/show_desktop", NULL))
 		return;
 
-#ifdef HAVE_GTK_MULTIHEAD
 	for (i = 0; bg_appliers [i]; i++)
 		bg_applier_apply_prefs (bg_appliers [i], prefs);
-#else
-	bg_applier_apply_prefs (bg_applier, prefs);
-#endif
 }
