@@ -38,8 +38,8 @@
 }
 
 static void
-_GSwitchItPluginManagerAddPluginsDir (GSwitchItPluginManager *
-				      manager, const char *dirname)
+_GSwitchItPluginManagerAddPluginsDir (GSwitchItPluginManager *manager,
+				      const char *dirname)
 {
 	GDir *dir = g_dir_open (dirname, 0, NULL);
 	const gchar *filename;
@@ -98,7 +98,7 @@ _GSwitchItPluginManagerAddPluginsDir (GSwitchItPluginManager *
 }
 
 static void
-_GSwitchItPluginManagerLoadAll (GSwitchItPluginManager * manager)
+_GSwitchItPluginManagerLoadAll (GSwitchItPluginManager *manager)
 {
 	if (!g_module_supported ()) {
 		XklDebug (0, "Modules are not supported - no plugins!\n");
@@ -108,8 +108,8 @@ _GSwitchItPluginManagerLoadAll (GSwitchItPluginManager * manager)
 }
 
 static void
-_GSwitchItPluginManagerRecTerm (GSwitchItPluginManagerRecord *
-				rec, void *userData)
+_GSwitchItPluginManagerRecTerm (GSwitchItPluginManagerRecord *rec,
+				void *userData)
 {
 	const GSwitchItPlugin *plugin = rec->plugin;
 	if (plugin != NULL) {
@@ -121,7 +121,7 @@ _GSwitchItPluginManagerRecTerm (GSwitchItPluginManagerRecord *
 }
 
 static void
-_GSwitchItPluginManagerRecDestroy (GSwitchItPluginManagerRecord * rec)
+_GSwitchItPluginManagerRecDestroy (GSwitchItPluginManagerRecord *rec)
 {
 	XklDebug (100, "Unloading plugin: [%s]...\n", rec->plugin->name);
 
@@ -130,7 +130,7 @@ _GSwitchItPluginManagerRecDestroy (GSwitchItPluginManagerRecord * rec)
 }
 
 void
-GSwitchItPluginManagerInit (GSwitchItPluginManager * manager)
+GSwitchItPluginManagerInit (GSwitchItPluginManager *manager)
 {
 	manager->allPluginRecs =
 	    g_hash_table_new_full (g_str_hash, g_str_equal,
@@ -141,7 +141,7 @@ GSwitchItPluginManagerInit (GSwitchItPluginManager * manager)
 }
 
 void
-GSwitchItPluginManagerTerm (GSwitchItPluginManager * manager)
+GSwitchItPluginManagerTerm (GSwitchItPluginManager *manager)
 {
 	GSwitchItPluginManagerTermInitializedPlugins (manager);
 	if (manager->allPluginRecs != NULL) {
@@ -151,10 +151,9 @@ GSwitchItPluginManagerTerm (GSwitchItPluginManager * manager)
 }
 
 void
-GSwitchItPluginManagerInitEnabledPlugins (GSwitchItPluginManager *
-					  manager,
-					  GSwitchItPluginContainer *
-					  pc, GSList * enabledPlugins)
+GSwitchItPluginManagerInitEnabledPlugins (GSwitchItPluginManager *manager,
+					  GSwitchItPluginContainer *pc,
+					  GSList *enabledPlugins)
 {
 	GSList *pluginNameNode = enabledPlugins;
 	if (manager->allPluginRecs == NULL)
@@ -194,8 +193,7 @@ GSwitchItPluginManagerInitEnabledPlugins (GSwitchItPluginManager *
 }
 
 void
-GSwitchItPluginManagerTermInitializedPlugins (GSwitchItPluginManager *
-					      manager)
+GSwitchItPluginManagerTermInitializedPlugins (GSwitchItPluginManager *manager)
 {
 
 	if (manager->initedPluginRecs == NULL)
@@ -207,9 +205,9 @@ GSwitchItPluginManagerTermInitializedPlugins (GSwitchItPluginManager *
 }
 
 void
-GSwitchItPluginManagerTogglePlugins (GSwitchItPluginManager * manager,
-				     GSwitchItPluginContainer * pc,
-				     GSList * enabledPlugins)
+GSwitchItPluginManagerTogglePlugins (GSwitchItPluginManager *manager,
+				     GSwitchItPluginContainer *pc,
+				     GSList *enabledPlugins)
 {
 	GSwitchItPluginManagerTermInitializedPlugins (manager);
 	GSwitchItPluginManagerInitEnabledPlugins (manager, pc,
@@ -217,8 +215,8 @@ GSwitchItPluginManagerTogglePlugins (GSwitchItPluginManager * manager,
 }
 
 void
-GSwitchItPluginManagerGroupChanged (GSwitchItPluginManager *
-				    manager, int newGroup)
+GSwitchItPluginManagerGroupChanged (GSwitchItPluginManager *manager,
+				    int newGroup)
 {
 	FOREACH_INITED_PLUGIN ();
 	if (plugin->groupChangedCallback)
@@ -226,8 +224,19 @@ GSwitchItPluginManagerGroupChanged (GSwitchItPluginManager *
 	NEXT_INITED_PLUGIN ();
 }
 
+void
+GSwitchItPluginManagerConfigChanged (GSwitchItPluginManager *manager, 
+				     GSwitchItKbdConfig *from,
+				     GSwitchItKbdConfig *to)
+{
+	FOREACH_INITED_PLUGIN ();
+	if (plugin->configChangedCallback)
+		(*plugin->configChangedCallback) (from, to);
+	NEXT_INITED_PLUGIN ();
+}
+
 const GSwitchItPlugin *
-GSwitchItPluginManagerGetPlugin (GSwitchItPluginManager * manager,
+GSwitchItPluginManagerGetPlugin (GSwitchItPluginManager *manager,
 				 const char *fullPath)
 {
 	GSwitchItPluginManagerRecord *rec =
@@ -240,9 +249,8 @@ GSwitchItPluginManagerGetPlugin (GSwitchItPluginManager * manager,
 }
 
 void
-GSwitchItPluginManagerPromotePlugin (GSwitchItPluginManager *
-				     manager,
-				     GSList * enabledPlugins,
+GSwitchItPluginManagerPromotePlugin (GSwitchItPluginManager *manager,
+				     GSList *enabledPlugins,
 				     const char *fullPath)
 {
 	GSList *theNode = enabledPlugins;
@@ -263,9 +271,8 @@ GSwitchItPluginManagerPromotePlugin (GSwitchItPluginManager *
 }
 
 void
-GSwitchItPluginManagerDemotePlugin (GSwitchItPluginManager *
-				    manager,
-				    GSList * enabledPlugins,
+GSwitchItPluginManagerDemotePlugin (GSwitchItPluginManager *manager,
+				    GSList *enabledPlugins,
 				    const char *fullPath)
 {
 	GSList *theNode = g_slist_find_custom (enabledPlugins, fullPath,
@@ -281,9 +288,8 @@ GSwitchItPluginManagerDemotePlugin (GSwitchItPluginManager *
 }
 
 void
-GSwitchItPluginManagerEnablePlugin (GSwitchItPluginManager *
-				    manager,
-				    GSList ** pEnabledPlugins,
+GSwitchItPluginManagerEnablePlugin (GSwitchItPluginManager *manager,
+				    GSList **pEnabledPlugins,
 				    const char *fullPath)
 {
 	if (NULL != GSwitchItPluginManagerGetPlugin (manager, fullPath)) {
@@ -294,9 +300,8 @@ GSwitchItPluginManagerEnablePlugin (GSwitchItPluginManager *
 }
 
 void
-GSwitchItPluginManagerDisablePlugin (GSwitchItPluginManager *
-				     manager,
-				     GSList ** pEnabledPlugins,
+GSwitchItPluginManagerDisablePlugin (GSwitchItPluginManager *manager,
+				     GSList **pEnabledPlugins,
 				     const char *fullPath)
 {
 	GSList *theNode = g_slist_find_custom (*pEnabledPlugins, fullPath,
@@ -309,8 +314,9 @@ GSwitchItPluginManagerDisablePlugin (GSwitchItPluginManager *
 }
 
 int
-GSwitchItPluginManagerWindowCreated (GSwitchItPluginManager *
-				     manager, Window win, Window parent)
+GSwitchItPluginManagerWindowCreated (GSwitchItPluginManager *manager,
+				     Window win,
+				     Window parent)
 {
 	FOREACH_INITED_PLUGIN ();
 	if (plugin->windowCreatedCallback) {
@@ -328,13 +334,11 @@ GSwitchItPluginManagerWindowCreated (GSwitchItPluginManager *
 }
 
 GtkWidget *
-GSwitchItPluginManagerDecorateWidget (GSwitchItPluginManager *
-				      manager,
-				      GtkWidget * widget,
+GSwitchItPluginManagerDecorateWidget (GSwitchItPluginManager *manager,
+				      GtkWidget *widget,
 				      const gint group,
-				      const char
-				      *groupDescription,
-				      GSwitchItKbdConfig * kbdConfig)
+				      const char *groupDescription,
+				      GSwitchItKbdConfig *kbdConfig)
 {
 	FOREACH_INITED_PLUGIN ();
 	if (plugin->decorateWidgetCallback) {
@@ -354,11 +358,10 @@ GSwitchItPluginManagerDecorateWidget (GSwitchItPluginManager *
 }
 
 void
-GSwitchItPluginManagerConfigurePlugin (GSwitchItPluginManager *
-				       manager,
-				       GSwitchItPluginContainer * pc,
+GSwitchItPluginManagerConfigurePlugin (GSwitchItPluginManager *manager,
+				       GSwitchItPluginContainer *pc,
 				       const char *fullPath,
-				       GtkWindow * parent)
+				       GtkWindow *parent)
 {
 	const GSwitchItPlugin *plugin =
 	    GSwitchItPluginManagerGetPlugin (manager, fullPath);
@@ -367,21 +370,21 @@ GSwitchItPluginManagerConfigurePlugin (GSwitchItPluginManager *
 }
 
 void
-GSwitchItPluginContainerInit (GSwitchItPluginContainer * pc,
-			      GConfClient * confClient)
+GSwitchItPluginContainerInit (GSwitchItPluginContainer *pc,
+			      GConfClient *confClient)
 {
 	pc->confClient = confClient;
 	g_object_ref (pc->confClient);
 }
 
 void
-GSwitchItPluginContainerTerm (GSwitchItPluginContainer * pc)
+GSwitchItPluginContainerTerm (GSwitchItPluginContainer *pc)
 {
 	g_object_unref (pc->confClient);
 }
 
 guint
-GSwitchItPluginGetNumGroups (GSwitchItPluginContainer * pc)
+GSwitchItPluginGetNumGroups (GSwitchItPluginContainer *pc)
 {
 	return XklGetNumGroups ();
 }
